Class: Wavix::CallControl::Types::CallDtmfCollectRequestPromptSay

Inherits:
Internal::Types::Model show all
Defined in:
lib/wavix/call_control/types/call_dtmf_collect_request_prompt_say.rb

Overview

Text to speak and voice to use. Pick voice from the language family matching language (for example, a German voice such as Hans for ge, a Spanish voice such as Conchita for sp) — Wavix does not validate the pairing itself.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Wavix::Internal::Types::Model