Class: Wavix::Types::TenDlcCampaignNudgeRequest

Inherits:
Internal::Types::Model show all
Defined in:
lib/wavix/types/ten_dlc_campaign_nudge_request.rb

Overview

Nudge configuration. Set the nudge intent to REVIEW to request action on a pending approval, or to APPEAL_REJECTION to submit an appeal for a rejected campaign.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Wavix::Internal::Types::Model